pub struct ActionDescriptor {
pub name: String,
pub description: String,
pub category: String,
pub requires_approval: bool,
}Fields
name: Stringdescription: Stringcategory: Stringrequires_approval: boolTrait Implementations
Sourceimpl Clone for ActionDescriptor
impl Clone for ActionDescriptor
Sourcefn clone(&self) -> ActionDescriptor
fn clone(&self) -> ActionDescriptor
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActionDescriptor
impl Debug for ActionDescriptor
Sourceimpl<'de> Deserialize<'de> for ActionDescriptor
impl<'de> Deserialize<'de> for ActionDescriptor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ActionDescriptor
impl JsonSchema for ActionDescriptor
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ActionDescriptor
impl RefUnwindSafe for ActionDescriptor
impl Send for ActionDescriptor
impl Sync for ActionDescriptor
impl Unpin for ActionDescriptor
impl UnsafeUnpin for ActionDescriptor
impl UnwindSafe for ActionDescriptor