pub struct BrowserSnapshot {
pub current_url: Option<String>,
pub title: Option<String>,
pub dom_html: Option<String>,
pub console_logs: Vec<String>,
pub network_events: Vec<String>,
}Fields
current_url: Option<String>title: Option<String>dom_html: Option<String>console_logs: Vec<String>network_events: Vec<String>Trait Implementations
Sourceimpl Clone for BrowserSnapshot
impl Clone for BrowserSnapshot
Sourcefn clone(&self) -> BrowserSnapshot
fn clone(&self) -> BrowserSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BrowserSnapshot
impl Debug for BrowserSnapshot
Sourceimpl<'de> Deserialize<'de> for BrowserSnapshot
impl<'de> Deserialize<'de> for BrowserSnapshot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BrowserSnapshot
impl JsonSchema for BrowserSnapshot
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BrowserSnapshot
impl RefUnwindSafe for BrowserSnapshot
impl Send for BrowserSnapshot
impl Sync for BrowserSnapshot
impl Unpin for BrowserSnapshot
impl UnsafeUnpin for BrowserSnapshot
impl UnwindSafe for BrowserSnapshot