pub struct CreateSessionRequest {
pub provider: String,
pub width: u32,
pub height: u32,
pub display: Option<String>,
pub browser_command: Option<String>,
pub boot: Option<String>,
pub container_image: Option<String>,
pub disable_kvm: Option<bool>,
pub qemu_profile: Option<String>,
pub shared_host_path: Option<String>,
}Fields
provider: Stringwidth: u32height: u32display: Option<String>browser_command: Option<String>boot: Option<String>container_image: Option<String>disable_kvm: Option<bool>qemu_profile: Option<String>Trait Implementations
Sourceimpl Clone for CreateSessionRequest
impl Clone for CreateSessionRequest
Sourcefn clone(&self) -> CreateSessionRequest
fn clone(&self) -> CreateSessionRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateSessionRequest
impl Debug for CreateSessionRequest
Sourceimpl<'de> Deserialize<'de> for CreateSessionRequest
impl<'de> Deserialize<'de> for CreateSessionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateSessionRequest
impl JsonSchema for CreateSessionRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateSessionRequest
impl RefUnwindSafe for CreateSessionRequest
impl Send for CreateSessionRequest
impl Sync for CreateSessionRequest
impl Unpin for CreateSessionRequest
impl UnsafeUnpin for CreateSessionRequest
impl UnwindSafe for CreateSessionRequest