pub struct CursorPosition {
pub x: i32,
pub y: i32,
pub screen: Option<String>,
}Fields
x: i32y: i32screen: Option<String>Trait Implementations
Sourceimpl Clone for CursorPosition
impl Clone for CursorPosition
Sourcefn clone(&self) -> CursorPosition
fn clone(&self) -> CursorPosition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CursorPosition
impl Debug for CursorPosition
Sourceimpl<'de> Deserialize<'de> for CursorPosition
impl<'de> Deserialize<'de> for CursorPosition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CursorPosition
impl JsonSchema for CursorPosition
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CursorPosition
impl RefUnwindSafe for CursorPosition
impl Send for CursorPosition
impl Sync for CursorPosition
impl Unpin for CursorPosition
impl UnsafeUnpin for CursorPosition
impl UnwindSafe for CursorPosition