pub struct LiveDesktopView {
pub mode: String,
pub status: String,
pub provider_surface: String,
pub matches_action_plane: bool,
pub canonical_url: Option<String>,
pub debug_url: Option<String>,
pub reason: Option<String>,
pub refresh_interval_ms: Option<u64>,
}Fields
mode: Stringstatus: Stringprovider_surface: Stringmatches_action_plane: boolcanonical_url: Option<String>debug_url: Option<String>reason: Option<String>refresh_interval_ms: Option<u64>Trait Implementations
Sourceimpl Clone for LiveDesktopView
impl Clone for LiveDesktopView
Sourcefn clone(&self) -> LiveDesktopView
fn clone(&self) -> LiveDesktopView
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LiveDesktopView
impl Debug for LiveDesktopView
Sourceimpl<'de> Deserialize<'de> for LiveDesktopView
impl<'de> Deserialize<'de> for LiveDesktopView
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LiveDesktopView
impl JsonSchema for LiveDesktopView
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LiveDesktopView
impl PartialEq for LiveDesktopView
Sourceimpl Serialize for LiveDesktopView
impl Serialize for LiveDesktopView
impl Eq for LiveDesktopView
impl StructuralPartialEq for LiveDesktopView