pub struct Observation {
pub captured_at: DateTime<Utc>,
pub screenshot: ScreenshotData,
pub active_window: Option<WindowMetadata>,
pub cursor_position: Option<CursorPosition>,
pub capability_flags: Vec<String>,
pub browser: Option<BrowserSnapshot>,
pub raw: Value,
pub summary: Value,
}Fields
captured_at: DateTime<Utc>screenshot: ScreenshotDataactive_window: Option<WindowMetadata>cursor_position: Option<CursorPosition>capability_flags: Vec<String>browser: Option<BrowserSnapshot>raw: Valuesummary: ValueTrait Implementations
Sourceimpl Clone for Observation
impl Clone for Observation
Sourcefn clone(&self) -> Observation
fn clone(&self) -> Observation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Observation
impl Debug for Observation
Sourceimpl<'de> Deserialize<'de> for Observation
impl<'de> Deserialize<'de> for Observation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Observation
impl JsonSchema for Observation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for Observation
impl RefUnwindSafe for Observation
impl Send for Observation
impl Sync for Observation
impl Unpin for Observation
impl UnsafeUnpin for Observation
impl UnwindSafe for Observation