pub struct RuntimeCapabilities {
pub actions: Vec<ActionDescriptor>,
pub provider: String,
pub browser_mode: String,
pub vm_mode: String,
pub enrichments: Vec<String>,
}Fields
actions: Vec<ActionDescriptor>provider: Stringbrowser_mode: Stringvm_mode: Stringenrichments: Vec<String>Trait Implementations
Sourceimpl Clone for RuntimeCapabilities
impl Clone for RuntimeCapabilities
Sourcefn clone(&self) -> RuntimeCapabilities
fn clone(&self) -> RuntimeCapabilities
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuntimeCapabilities
impl Debug for RuntimeCapabilities
Sourceimpl<'de> Deserialize<'de> for RuntimeCapabilities
impl<'de> Deserialize<'de> for RuntimeCapabilities
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RuntimeCapabilities
impl JsonSchema for RuntimeCapabilities
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RuntimeCapabilities
impl RefUnwindSafe for RuntimeCapabilities
impl Send for RuntimeCapabilities
impl Sync for RuntimeCapabilities
impl Unpin for RuntimeCapabilities
impl UnsafeUnpin for RuntimeCapabilities
impl UnwindSafe for RuntimeCapabilities