pub struct ScreenshotData {
pub mime_type: String,
pub data_base64: Option<String>,
pub width: Option<u32>,
pub height: Option<u32>,
pub artifact_path: Option<String>,
}Fields
mime_type: Stringdata_base64: Option<String>width: Option<u32>height: Option<u32>artifact_path: Option<String>Trait Implementations
Sourceimpl Clone for ScreenshotData
impl Clone for ScreenshotData
Sourcefn clone(&self) -> ScreenshotData
fn clone(&self) -> ScreenshotData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScreenshotData
impl Debug for ScreenshotData
Sourceimpl<'de> Deserialize<'de> for ScreenshotData
impl<'de> Deserialize<'de> for ScreenshotData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScreenshotData
impl JsonSchema for ScreenshotData
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ScreenshotData
impl RefUnwindSafe for ScreenshotData
impl Send for ScreenshotData
impl Sync for ScreenshotData
impl Unpin for ScreenshotData
impl UnsafeUnpin for ScreenshotData
impl UnwindSafe for ScreenshotData