pub struct SessionRecord {Show 17 fields
pub id: String,
pub provider: String,
pub qemu_profile: Option<String>,
pub display: Option<String>,
pub width: u32,
pub height: u32,
pub state: String,
pub created_at: DateTime<Utc>,
pub artifacts_dir: String,
pub capabilities: Vec<String>,
pub browser_command: Option<String>,
pub runtime_base_url: Option<String>,
pub viewer_url: Option<String>,
pub live_desktop_view: Option<LiveDesktopView>,
pub bridge_status: Option<String>,
pub readiness_state: Option<String>,
pub bridge_error: Option<StructuredError>,
}Fields
id: Stringprovider: Stringqemu_profile: Option<String>display: Option<String>width: u32height: u32state: Stringcreated_at: DateTime<Utc>artifacts_dir: Stringcapabilities: Vec<String>browser_command: Option<String>runtime_base_url: Option<String>viewer_url: Option<String>live_desktop_view: Option<LiveDesktopView>bridge_status: Option<String>readiness_state: Option<String>bridge_error: Option<StructuredError>Trait Implementations
Sourceimpl Clone for SessionRecord
impl Clone for SessionRecord
Sourcefn clone(&self) -> SessionRecord
fn clone(&self) -> SessionRecord
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionRecord
impl Debug for SessionRecord
Sourceimpl<'de> Deserialize<'de> for SessionRecord
impl<'de> Deserialize<'de> for SessionRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SessionRecord
impl JsonSchema for SessionRecord
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionRecord
impl RefUnwindSafe for SessionRecord
impl Send for SessionRecord
impl Sync for SessionRecord
impl Unpin for SessionRecord
impl UnsafeUnpin for SessionRecord
impl UnwindSafe for SessionRecord