pub struct StructuredError {
pub code: String,
pub message: String,
pub retryable: bool,
pub category: String,
pub details: Value,
pub artifact_refs: Vec<ArtifactRef>,
}Fields
code: Stringmessage: Stringretryable: boolcategory: Stringdetails: Valueartifact_refs: Vec<ArtifactRef>Trait Implementations
Sourceimpl Clone for StructuredError
impl Clone for StructuredError
Sourcefn clone(&self) -> StructuredError
fn clone(&self) -> StructuredError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StructuredError
impl Debug for StructuredError
Sourceimpl<'de> Deserialize<'de> for StructuredError
impl<'de> Deserialize<'de> for StructuredError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StructuredError
impl JsonSchema for StructuredError
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StructuredError
impl RefUnwindSafe for StructuredError
impl Send for StructuredError
impl Sync for StructuredError
impl Unpin for StructuredError
impl UnsafeUnpin for StructuredError
impl UnwindSafe for StructuredError