pub struct WindowMetadata {
pub id: Option<String>,
pub title: Option<String>,
pub class_name: Option<String>,
}Fields
id: Option<String>title: Option<String>class_name: Option<String>Trait Implementations
Sourceimpl Clone for WindowMetadata
impl Clone for WindowMetadata
Sourcefn clone(&self) -> WindowMetadata
fn clone(&self) -> WindowMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WindowMetadata
impl Debug for WindowMetadata
Sourceimpl<'de> Deserialize<'de> for WindowMetadata
impl<'de> Deserialize<'de> for WindowMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WindowMetadata
impl JsonSchema for WindowMetadata
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WindowMetadata
impl RefUnwindSafe for WindowMetadata
impl Send for WindowMetadata
impl Sync for WindowMetadata
impl Unpin for WindowMetadata
impl UnsafeUnpin for WindowMetadata
impl UnwindSafe for WindowMetadata